summaryrefslogtreecommitdiffstats
path: root/src/usr/fapi2/plat_hw_access.C
diff options
context:
space:
mode:
authorKahn Evans <kahnevan@us.ibm.com>2017-03-21 10:43:26 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-04-11 17:02:34 -0400
commite9c91c9d51b90d2fbc94e64d8fe8a109fcb3cbbc (patch)
treeb5c649600f6d3388870c338a132bb1645459ac36 /src/usr/fapi2/plat_hw_access.C
parentf9a4434b9a54ca4355e1c368f91497b629130ad8 (diff)
downloadtalos-hostboot-e9c91c9d51b90d2fbc94e64d8fe8a109fcb3cbbc.tar.gz
talos-hostboot-e9c91c9d51b90d2fbc94e64d8fe8a109fcb3cbbc.zip
Change RingID to RingId_t in putRing
Change-Id: If809a8ec82ff90a6ed9dc2763f7e609524fc75fb Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/38351 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Reviewed-by: RANGANATHPRASAD G. BRAHMASAMUDRA <prasadbgr@in.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/38354 Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com>
Diffstat (limited to 'src/usr/fapi2/plat_hw_access.C')
-rw-r--r--src/usr/fapi2/plat_hw_access.C16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/usr/fapi2/plat_hw_access.C b/src/usr/fapi2/plat_hw_access.C
index 5626bf4d2..88686c1f7 100644
--- a/src/usr/fapi2/plat_hw_access.C
+++ b/src/usr/fapi2/plat_hw_access.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2016 */
+/* Contributors Listed Below - COPYRIGHT 2016,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -912,12 +912,12 @@ ReturnCode platModifyRing(const Target<TARGET_TYPE_ALL>& i_target,
return l_rc;
}
/// @brief passing a 'Put Ring from Image' message to SBE with RingID
ReturnCode platPutRing(const Target<TARGET_TYPE_ALL>& i_target,
- const RingID i_ringID,
+ const RingId_t i_ringID,
const RingMode i_ringMode = RING_MODE_HEADER_CHECK)
{
- FAPI_DBG("Entering: platPutRing() with RingID");
+ FAPI_DBG("Entering: platPutRing() with RingId_t");
ReturnCode l_rc = FAPI2_RC_SUCCESS;
errlHndl_t l_err = NULL;
@@ -925,8 +925,8 @@ ReturnCode platPutRing(const Target<TARGET_TYPE_ALL>& i_target,
// trace in common fapi2_hw_access.H
bool l_traceit = platIsScanTraceEnabled();
- //convert const ringID to ringID
- RingID l_ringID = reinterpret_cast<RingID>(i_ringID);
+ //convert const RingId_t to RingId_t
+ RingId_t l_ringID = reinterpret_cast<RingId_t>(i_ringID);
// Extract the component pointer
TARGETING::Target* l_target =
@@ -961,12 +961,12 @@ ReturnCode platPutRing(const Target<TARGET_TYPE_ALL>& i_target,
if (l_traceit)
{
- FAPI_SCAN("TRACE : PUTRING w RingID : %s : %.16llX",
+ FAPI_SCAN("TRACE : PUTRING w RingId_t : %s : %.16llX",
l_targName,
static_cast<uint64_t>(l_ringID));
}
- FAPI_DBG(EXIT_MRK "platPutRing() with RingID");
+ FAPI_DBG(EXIT_MRK "platPutRing() with RingId_t");
return l_rc;
}
OpenPOWER on IntegriCloud
@@ -912,12 +912,12 @@ ReturnCode platModifyRing(const Target<TARGET_TYPE_ALL>& i_target,
return l_rc;
}
-/// @brief passing a 'Put Ring from Image' message to SBE with RingID
+/// @brief passing a 'Put Ring from Image' message to SBE with RingId_t
ReturnCode platPutRing(const Target<TARGET_TYPE_ALL>& i_target,